@@ -82,6 +82,22 @@ YAZ_EXPORT size_t yaz_write_UTF8_char(unsigned long x,
                                       char **outbuf, size_t *outbytesleft,
                                       int *error);
 
+/* ctype.h macros ASCII based. That do not depend on LANG, nor require
+   unsigned int as argument */
+#define yaz_isdigit(x) ((x) >= '0' && (x) <= '9')
+#define yaz_isspace(x) strchr(" \f\r\n\t\v", x)
+#define yaz_toupper(x) ((x) + ('A' - 'a'))
+#define yaz_isupper(x) ((x) >= 'A' && (x) <= 'Z')
+#define yaz_tolower(x) ((x) + ('a' - 'A'))
+#define yaz_islower(x) ((x) >= 'a' && (x) <= 'z')
+
+/** \brief check whether string apppers to be UTF-8 encoded
+    \param cstr string to check
+    \retval 1 OK (appears to be UTF-8)
+    \retval 0 definitely not UTF-8
+*/
+YAZ_EXPORT int yaz_utf8_check(const char *cstr);
+
 YAZ_END_CDECL
 
 #endif
